package com.ruoyi.frequency.withdrawalconfig.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.withdrawalconfig.entity.WithdrawalConfig;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 提现配置Mapper接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface WithdrawalConfigMapper  extends BaseMapper<WithdrawalConfig>
{
    /**
     * 查询提现配置
     * 
     * @param id 提现配置主键
     * @return 提现配置
     */
    WithdrawalConfig selectWithdrawalConfigById(Long id);

    /**
     * 查询提现配置列表
     * 
     * @param withdrawalConfig 提现配置
     * @return 提现配置集合
     */
    List<WithdrawalConfig> selectWithdrawalConfigList(WithdrawalConfig withdrawalConfig);

    /**
     * 新增提现配置
     * 
     * @param withdrawalConfig 提现配置
     * @return 结果
     */
    int insertWithdrawalConfig(WithdrawalConfig withdrawalConfig);

    /**
     * 修改提现配置
     * 
     * @param withdrawalConfig 提现配置
     * @return 结果
     */
    int updateWithdrawalConfig(WithdrawalConfig withdrawalConfig);

    /**
     * 删除提现配置
     * 
     * @param id 提现配置主键
     * @return 结果
     */
    int deleteWithdrawalConfigById(Long id);

    /**
     * 批量删除提现配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteWithdrawalConfigByIds(Long[] ids);

    WithdrawalConfig getWithdrawalData(@Param("userVo") UserVo userVo);
}
